@@ -3,7 +3,7 @@ from selenium import webdriver
 from selenium.webdriver.support.event_firing_webdriver import EventFiringWebDriver
 from webdriver_manager.chrome import ChromeDriverManager
 
-from src.seleniumPythonFramework_VeriSoft.infra.CustomEventListener import CustomEventListener
+from seleniumPythonFramework_VeriSoft.infra.CustomEventListener import CustomEventListener
 
 """
 setup and cleanup fixtures functions to init and close the driver. 
